@@ -59,29 +59,23 @@ class Config:
 	DEFAULT_ICONSET = 'dcraven'
 	DEFAULT_MOOD_ICONSET = 'default'
 	DEFAULT_ACTIVITY_ICONSET = 'default'
-	if sys.platform == 'darwin':
-		DEFAULT_OPENWITH = 'open'
-		DEFAULT_BROWSER = 'open -a Safari'
-		DEFAULT_MAILAPP = 'open -a Mail'
-		DEFAULT_FILE_MANAGER = 'open -a Finder'
-	else:
-		DEFAULT_OPENWITH = 'gnome-open'
-		DEFAULT_BROWSER = 'firefox'
-		DEFAULT_MAILAPP = 'mozilla-thunderbird -compose'
-		DEFAULT_FILE_MANAGER = 'xffm'
+	DEFAULT_OPENWITH = 'gnome-open'
+	DEFAULT_BROWSER = 'firefox'
+	DEFAULT_MAILAPP = 'mozilla-thunderbird -compose'
+	DEFAULT_FILE_MANAGER = 'xffm'
 
 	__options = {
 		# name: [ type, default_value, help_string ]
 		'verbose': [ opt_bool, False, '', True ],
-		'alwaysauth': [ opt_bool, False ],
 		'autopopup': [ opt_bool, False ],
 		'notify_on_signin': [ opt_bool, True ],
 		'notify_on_signout': [ opt_bool, False ],
 		'notify_on_new_message': [ opt_bool, True ],
 		'autopopupaway': [ opt_bool, False ],
+		'sounddnd': [ opt_bool, False, _('Play sound when user is busy')],
 		'use_notif_daemon': [ opt_bool, True , _('Use D-Bus and Notification-Daemon to show notifications') ],
-		'ignore_unknown_contacts': [ opt_bool, False ],
 		'showoffline': [ opt_bool, False ],
+		'show_only_chat_and_online': [ opt_bool, False, _('Show only online and free for chat contacts in roster.')],
 		'show_transports_group': [ opt_bool, True ],
 		'autoaway': [ opt_bool, True ],
 		'autoawaytime': [ opt_int, 5, _('Time in minutes, after which your status changes to away.') ],
@@ -91,29 +85,28 @@ class Config:
 		'autoxa_message': [ opt_str, _('$S (Not available as a result of being idle more than $T min)'), _('$S will be replaced by current status message, $T by autoxa time.') ],
 		'ask_online_status': [ opt_bool, False ],
 		'ask_offline_status': [ opt_bool, False ],
-		'last_status_msg_online': [ opt_str, '' ],
-		'last_status_msg_chat': [ opt_str, '' ],
-		'last_status_msg_away': [ opt_str, '' ],
-		'last_status_msg_xa': [ opt_str, '' ],
-		'last_status_msg_dnd': [ opt_str, '' ],
-		'last_status_msg_invisible': [ opt_str, '' ],
-		'last_status_msg_offline': [ opt_str, '' ],
-		'trayicon': [ opt_bool, True, '', True ],
+		'trayicon': [opt_str, 'always', _("When to show systray icon. Can be 'never', 'on_event', 'always'."), True],
 		'iconset': [ opt_str, DEFAULT_ICONSET, '', True ],
 		'mood_iconset': [ opt_str, DEFAULT_MOOD_ICONSET, '', True ],
 		'activity_iconset': [ opt_str, DEFAULT_ACTIVITY_ICONSET, '', True ],
 		'use_transports_iconsets': [ opt_bool, True, '', True ],
-		'inmsgcolor': [ opt_color, '#a34526', '', True ],
-		'outmsgcolor': [ opt_color, '#164e6f', '', True ],
-		'statusmsgcolor': [ opt_color, '#1eaa1e', '', True ],
+		'inmsgcolor': [ opt_color, '#a40000', _('Incoming nickname color.'), True ],
+		'outmsgcolor': [ opt_color, '#3465a4', _('Outgoing nickname color.'), True ],
+		'inmsgtxtcolor': [ opt_color, '', _('Incoming text color.'), True ],
+		'outmsgtxtcolor': [ opt_color, '#555753', _('Outgoing text color.'), True ],
+		'statusmsgcolor': [ opt_color, '#4e9a06', _('Status message text color.'), True ],
 		'markedmsgcolor': [ opt_color, '#ff8080', '', True ],
-		'urlmsgcolor': [ opt_color, '#0000ff', '', True ],
+		'urlmsgcolor': [ opt_color, '#204a87', '', True ],
+		'inmsgfont': [ opt_str, '', _('Incoming nickname font.'), True ],
+		'outmsgfont': [ opt_str, '', _('Outgoing nickname font.'), True ],
+		'inmsgtxtfont': [ opt_str, '', _('Incoming text font.'), True ],
+		'outmsgtxtfont': [ opt_str, '', _('Outgoing text font.'), True ],
+		'statusmsgfont': [ opt_str, '', _('Status message text font.'), True ],
 		'collapsed_rows': [ opt_str, '', _('List (space separated) of rows (accounts and groups) that are collapsed.'), True ],
 		'roster_theme': [ opt_str, _('default'), '', True ],
 		'mergeaccounts': [ opt_bool, False, '', True ],
 		'sort_by_show_in_roster': [ opt_bool, True, '', True ],
 		'sort_by_show_in_muc': [ opt_bool, False, '', True ],
-		'enable_zeroconf': [opt_bool, False, _('Enable link-local/zeroconf messaging')],
 		'use_speller': [ opt_bool, False, ],
 		'ignore_incoming_xhtml': [ opt_bool, False, ],
 		'speller_language': [ opt_str, '', _('Language used by speller')],
@@ -136,6 +129,7 @@ class Config:
 		'gc-hpaned-position': [opt_int, 430],
 		'gc_refer_to_nick_char': [opt_str, ',', _('Character to add after nickname when using nick completion (tab) in group chat.')],
 		'gc_proposed_nick_char': [opt_str, '_', _('Character to propose to add after desired nickname when desired nickname is used by someone else in group chat.')],
+		'msgwin-max-state': [opt_bool, False],
 		'msgwin-x-position': [opt_int, -1], # Default is to let the window manager decide
 		'msgwin-y-position': [opt_int, -1], # Default is to let the window manager decide
 		'msgwin-width': [opt_int, 500],
@@ -156,18 +150,25 @@ class Config:
 		'roster_y-position': [ opt_int, 0 ],
 		'roster_width': [ opt_int, 200 ],
 		'roster_height': [ opt_int, 400 ],
+		'history_window_width': [ opt_int, 650 ],
+		'history_window_height': [ opt_int, 450 ],
+		'history_window_x-position': [ opt_int, 0 ],
+		'history_window_y-position': [ opt_int, 0 ],
 		'latest_disco_addresses': [ opt_str, '' ],
 		'recently_groupchat': [ opt_str, '' ],
 		'time_stamp': [ opt_str, '[%X] ', _('This option let you customize timestamp that is printed in conversation. For exemple "[%H:%M] " will show "[hour:minute] ". See python doc on strftime for full documentation: http://docs.python.org/lib/module-time.html') ],
 		'before_nickname': [ opt_str, '', _('Characters that are printed before the nickname in conversations') ],
 		'after_nickname': [ opt_str, ':', _('Characters that are printed after the nickname in conversations') ],
-		'send_os_info': [ opt_bool, True ],
 		'notify_on_new_gmail_email': [ opt_bool, True ],
 		'notify_on_new_gmail_email_extra': [ opt_bool, False ],
 		'use_gpg_agent': [ opt_bool, False ],
 		'change_roster_title': [ opt_bool, True, _('Add * and [n] in roster title?')],
 		'restore_lines': [opt_int, 4, _('How many lines to remember from previous conversation when a chat tab/window is reopened.')],
 		'restore_timeout': [opt_int, 60, _('How many minutes should last lines from previous conversation last.')],
+		'muc_restore_lines': [opt_int, 20, _('How many lines to request to server when entering a groupchat.')],
+		'muc_restore_timeout': [opt_int, 60, _('How many minutes back to request logs when a entering a groupchat.')],
+		'muc_autorejoin_timeout': [opt_int, 1, _('How many seconds to wait before trying to autorejoin to a conference you are being disconnected from. Set to 0 to disable autorejoining.')],
+		'muc_autorejoin_on_kick': [opt_bool, False, 'Should autorejoin be activated when we are being kicked from a conference?'],
 		'send_on_ctrl_enter': [opt_bool, False, _('Send message on Ctrl+Enter and with Enter make new line (Mirabilis ICQ Client default behaviour).')],
 		'show_roster_on_startup': [opt_bool, True],
 		'key_up_lines': [opt_int, 25, _('How many lines to store for Ctrl+KeyUP.')],
@@ -185,9 +186,10 @@ class Config:
 		'confirm_close_muc': [opt_bool, True, _('Ask before closing a group chat tab/window.')],
 		'confirm_close_muc_rooms': [opt_str, '', _('Always ask before closing group chat tab/window in this space separated list of group chat jids.')],
 		'noconfirm_close_muc_rooms': [opt_str, '', _('Never ask before closing group chat tab/window in this space separated list of group chat jids.')],
+		'confirm_close_multiple_tabs': [opt_bool, True, _('Ask before closing tabbed chat window if there are control that can loose data (chat, private chat, groupchat that will not be minimized)')],
 		'notify_on_file_complete': [opt_bool, True],
 		'file_transfers_port': [opt_int, 28011],
-		'ft_add_hosts_to_send': [opt_str, '', _('Comma separated list of hosts that we send, in addition of local interfaces, for File Transfer in case of address translation/port forwarding.')], 
+		'ft_add_hosts_to_send': [opt_str, '', _('Comma separated list of hosts that we send, in addition of local interfaces, for File Transfer in case of address translation/port forwarding.')],
 		'conversation_font': [opt_str, ''],
 		'use_kib_mib': [opt_bool, False, _('IEC standard says KiB = 1024 bytes, KB = 1000 bytes.')],
 		'notify_on_all_muc_messages': [opt_bool, False],
@@ -200,7 +202,6 @@ class Config:
 		'tabs_always_visible': [opt_bool, False, _('Show tab when only one conversation?')],
 		'tabs_border': [opt_bool, False, _('Show tabbed notebook border in chat windows?')],
 		'tabs_close_button': [opt_bool, True, _('Show close button in tab?')],
-		'log_encrypted_sessions': [opt_bool, True, _('When negotiating an encrypted session, should Gajim assume you want your messages to be logged?')],
 		'esession_modp': [opt_str, '5,14', _('A list of modp groups to use in a Diffie-Hellman, highest preference first, separated by commas. Valid groups are 1, 2, 5, 14, 15, 16, 17 and 18. Higher numbers are more secure, but take longer to calculate when you start a session.')],
 		'chat_avatar_width': [opt_int, 52],
 		'chat_avatar_height': [opt_int, 52],
@@ -231,7 +232,7 @@ class Config:
 		'log_contact_status_changes': [opt_bool, False],
 		'just_connected_bg_color': [opt_str, '#adc3c6', _('Background color of contacts when they just signed in.')],
 		'just_disconnected_bg_color': [opt_str, '#ab6161', _('Background color of contacts when they just signed out.')],
-		'restored_messages_color': [opt_str, 'grey'],
+		'restored_messages_color': [opt_color, '#555753'],
 		'restored_messages_small': [opt_bool, True, _('If True, restored messages will use a smaller font than the default one.')],
 		'hide_avatar_of_transport': [opt_bool, False, _('Don\'t show avatar for the transport itself.')],
 		'roster_window_skip_taskbar': [opt_bool, False, _('Don\'t show roster in the system taskbar.')],
@@ -250,11 +251,14 @@ class Config:
 		'chat_merge_consecutive_nickname': [opt_bool, False, _('In a chat, show the nickname at the beginning of a line only when it\'s not the same person talking than in previous message.')],
 		'chat_merge_consecutive_nickname_indent': [opt_str, '  ', _('Indentation when using merge consecutive nickname.')],
 		'use_smooth_scrolling': [opt_bool, True, _('Smooth scroll message in conversation window')],
-		'gc_nicknames_colors': [ opt_str, '#a34526:#c000ff:#0012ff:#388a99:#045723:#7c7c7c:#ff8a00:#94452d:#244b5a:#32645a', _('List of colors, separated by ":", that will be used to color nicknames in group chats.'), True ],
+		'gc_nicknames_colors': [ opt_str, '#4e9a06:#f57900:#ce5c00:#3465a4:#204a87:#75507b:#5c3566:#c17d11:#8f5902:#ef2929:#cc0000:#a40000', _('List of colors, separated by ":", that will be used to color nicknames in group chats.'), True ],
 		'ctrl_tab_go_to_next_composing': [opt_bool, True, _('Ctrl-Tab go to next composing tab when none is unread.')],
 		'confirm_metacontacts': [ opt_str, '', _('Should we show the confirm metacontacts creation dialog or not? Empty string means we never show the dialog.')],
+		'confirm_block': [ opt_str, '', _('Should we show the confirm block contact dialog or not? Empty string means we never show the dialog.')],
+		'confirm_custom_status': [ opt_str, '', _('Should we show the confirm custom status dialog or not? Empty string means we never show the dialog.')],
 		'enable_negative_priority': [ opt_bool, False, _('If True, you will be able to set a negative priority to your account in account modification window. BE CAREFUL, when you are logged in with a negative priority, you will NOT receive any message from your server.')],
 		'use_gnomekeyring': [opt_bool, True, _('If True, Gajim will use Gnome Keyring (if available) to store account passwords.')],
+		'use_kwalletcli': [opt_bool, True, _('If True, Gajim will use KDE Wallet (if kwalletcli is available) to store account passwords.')],
 		'show_contacts_number': [opt_bool, True, _('If True, Gajim will show number of online and total contacts in account and group rows.')],
 		'treat_incoming_messages': [ opt_str, '', _('Can be empty, \'chat\' or \'normal\'. If not empty, treat all incoming messages as if they were of this type')],
 		'scroll_roster_to_last_message': [opt_bool, True, _('If True, Gajim will scroll and select the contact who sent you the last message, if chat window is not already opened.')],
@@ -264,13 +268,17 @@ class Config:
 		'attach_notifications_to_systray': [opt_bool, False, _('If True, notification windows from notification-daemon will be attached to systray icon.')],
 		'check_idle_every_foo_seconds': [opt_int, 2, _('Choose interval between 2 checks of idleness.')],
 		'latex_png_dpi': [opt_str, '108',_('Change the value to change the size of latex formulas displayed. The higher is larger.') ],
-		'uri_schemes': [opt_str, 'aaa aaas acap cap cid crid data dav dict dns fax file ftp go gopher h323 http https icap im imap info ipp iris iris.beep iris.xpc iris.xpcs iris.lwz ldap mailto mid modem msrp msrps mtqp mupdate news nfs nntp opaquelocktoken pop pres rtsp service shttp sip sips snmp soap.beep soap.beeps tag tel telnet tftp thismessage tip tv urn vemmi xmlrpc.beep xmlrpc.beeps xmpp z39.50r z39.50s about cvs daap ed2k feed fish git iax2 irc ircs ldaps magnet mms rsync ssh svn sftp smb webcal', _('Valid uri schemes. Only schemes in this list will be made accepted as "real" uri.')],
+		'uri_schemes': [opt_str, 'aaa aaas acap cap cid crid data dav dict dns fax file ftp go gopher h323 http https icap im imap info ipp iris iris.beep iris.xpc iris.xpcs iris.lwz ldap mid modem msrp msrps mtqp mupdate news nfs nntp opaquelocktoken pop pres rtsp service shttp sip sips snmp soap.beep soap.beeps tag tel telnet tftp thismessage tip tv urn vemmi xmlrpc.beep xmlrpc.beeps z39.50r z39.50s about cvs daap ed2k feed fish git iax2 irc ircs ldaps magnet mms rsync ssh svn sftp smb webcal', _('Valid uri schemes. Only schemes in this list will be accepted as "real" uri. (mailto and xmpp are handled separately)'), True],
+		'ask_offline_status_on_connection': [ opt_bool, False, _('Ask offline status message to all offline contacts when connection to an accoutn is established. WARNING: This causes a lot of requests to be sent!') ],
+		'shell_like_completion': [ opt_bool, False, _('If True, completion in groupchats will be like a shell auto-completion')],
+		'show_self_contact': [opt_str, 'when_other_resource', _('When is self contact row displayed. Can be "always", "when_other_resource" or "never"'), True],
 	}
 
 	__options_per_key = {
 		'accounts': ({
 			'name': [ opt_str, '', '', True ],
 			'hostname': [ opt_str, '', '', True ],
+			'anonymous_auth': [ opt_bool, False ],
 			'savepass': [ opt_bool, False ],
 			'password': [ opt_str, '' ],
 			'resource': [ opt_str, 'gajim', '', True ],
@@ -286,7 +294,8 @@ class Config:
 			'autoconnect_as': [ opt_str, 'online', _('Status used to autoconnect as. Can be online, chat, away, xa, dnd, invisible. NOTE: this option is used only if restore_last_status is disabled'), True ],
 			'restore_last_status': [ opt_bool, False, _('If enabled, restore the last status that was used.') ],
 			'autoreconnect': [ opt_bool, True ],
-			'active': [ opt_bool, True],
+			'autoauth': [ opt_bool, False, _('If True, Contacts requesting authorization will be automatically accepted.')],
+			'active': [ opt_bool, True, _('If False, this account will be disabled and will not appear in roster window.'), True],
 			'proxy': [ opt_str, '', '', True ],
 			'keyid': [ opt_str, '', '', True ],
 			'gpg_sign_presence': [ opt_bool, True, _('If disabled, don\'t sign presences with GPG key, even if GPG is configured.') ],
@@ -306,17 +315,18 @@ class Config:
 			'no_log_for': [ opt_str, '' ],
 			'minimized_gc': [ opt_str, '' ],
 			'attached_gpg_keys': [ opt_str, '' ],
-			'keep_alives_enabled': [ opt_bool, True],
+			'keep_alives_enabled': [ opt_bool, True, _('Whitespace sent after inactivity')],
+			'ping_alives_enabled': [ opt_bool, True, _('XMPP ping sent after inactivity')],
 			# send keepalive every N seconds of inactivity
 			'keep_alive_every_foo_secs': [ opt_int, 55 ],
-			'time_for_keep_alive_answer': [ opt_int, 30, _('How many seconds to wait for the answer of keepalive packet before we try to reconnect.') ],
-			# try for 2 minutes before giving up (aka. timeout after those seconds)
+			'ping_alive_every_foo_secs': [ opt_int, 120 ],
+			'time_for_ping_alive_answer': [ opt_int, 60, _('How many seconds to wait for the answer of ping alive packet before we try to reconnect.') ],
+			# try for 1 minutes before giving up (aka. timeout after those seconds)
 			'try_connecting_for_foo_secs': [ opt_int, 60 ],
 			'http_auth': [opt_str, 'ask'], # yes, no, ask
 			'dont_ack_subscription': [opt_bool, False, _('Jabberd2 workaround')],
 			# proxy65 for FT
-			'file_transfer_proxies': [opt_str,
-			'proxy65.talkonaut.com, proxy.jabber.org, proxy.netlab.cz, transfer.jabber.freenet.de, proxy.jabber.cd.chalmers.se'],
+			'file_transfer_proxies': [opt_str, 'proxy.eu.jabber.org, proxy.jabber.ru, proxy.jabbim.cz'],
 			'use_ft_proxies': [opt_bool, True, _('If checked, Gajim will use your IP and proxies defined in file_transfer_proxies option for file transfer.'), True],
 			'msgwin-x-position': [opt_int, -1], # Default is to let the wm decide
 			'msgwin-y-position': [opt_int, -1], # Default is to let the wm decide
@@ -338,9 +348,18 @@ class Config:
 			'subscribe_activity': [opt_bool, True],
 			'subscribe_tune': [opt_bool, True],
 			'subscribe_nick': [opt_bool, True],
+			'ignore_unknown_contacts': [ opt_bool, False ],
+			'send_os_info': [ opt_bool, True ],
+			'log_encrypted_sessions': [opt_bool, True, _('When negotiating an encrypted session, should Gajim assume you want your messages to be logged?')],
+			'roster_version': [opt_str, ''],
 		}, {}),
 		'statusmsg': ({
 			'message': [ opt_str, '' ],
+			'activity': [ opt_str, '' ],
+			'subactivity': [ opt_str, '' ],
+			'activity_text': [ opt_str, '' ],
+			'mood': [ opt_str, '' ],
+			'mood_text': [ opt_str, '' ],
 		}, {}),
 		'defaultstatusmsg': ({
 			'enabled': [ opt_bool, False ],
@@ -354,8 +373,16 @@ class Config:
 			'type': [ opt_str, 'http' ],
 			'host': [ opt_str, '' ],
 			'port': [ opt_int, 3128 ],
+			'useauth': [ opt_bool, False ],
 			'user': [ opt_str, '' ],
 			'pass': [ opt_str, '' ],
+			'bosh_uri': [ opt_str, '' ],
+			'bosh_useproxy': [ opt_bool, False ],
+			'bosh_wait': [ opt_int, 30 ],
+			'bosh_hold': [ opt_int, 2 ],
+			'bosh_content': [ opt_str, 'text/xml; charset=utf-8' ],
+			'bosh_http_pipelining': [ opt_bool, False ],
+			'bosh_wait_for_restart_response': [ opt_bool, False ],
 		}, {}),
 		'themes': ({
 			'accounttextcolor': [ opt_color, 'black', '', True ],
@@ -412,13 +439,20 @@ class Config:
 	}
 
 	statusmsg_default = {
-		_('Sleeping'): 'ZZZZzzzzzZZZZZ',
-		_('Back soon'): _('Back in some minutes.'),
-		_('Eating'): _("I'm eating, so leave me a message."),
-		_('Movie'): _("I'm watching a movie."),
-		_('Working'): _("I'm working."),
-		_('Phone'): _("I'm on the phone."),
-		_('Out'): _("I'm out enjoying life."),
+		_('Sleeping'): [ 'ZZZZzzzzzZZZZZ', 'inactive', 'sleeping', '', 'sleepy', '' ],
+		_('Back soon'): [ _('Back in some minutes.'), '', '', '', '', '' ],
+		_('Eating'): [ _("I'm eating, so leave me a message."), 'eating', 'other', '', '', '' ],
+		_('Movie'): [ _("I'm watching a movie."), 'relaxing', 'watching_a_movie', '', '', '' ],
+		_('Working'): [ _("I'm working."), 'working', 'other', '', '', '' ],
+		_('Phone'): [ _("I'm on the phone."), 'talking', 'on_the_phone', '', '', '' ],
+		_('Out'): [ _("I'm out enjoying life."), 'relaxing', 'going_out', '', '', '' ],
+		'_last_online': ['', '', '', '', '', ''],
+		'_last_chat': ['', '', '', '', '', ''],
+		'_last_away': ['', '', '', '', '', ''],
+		'_last_xa': ['', '', '', '', '', ''],
+		'_last_dnd': ['', '', '', '', '', ''],
+		'_last_invisible': ['', '', '', '', '', ''],
+		'_last_offline': ['', '', '', '', '', ''],
 	}
 
 	defaultstatusmsg_default = {
@@ -432,15 +466,15 @@ class Config:
 	}
 
 	soundevents_default = {
-		'first_message_received': [ True, '../data/sounds/message1.wav' ],
-		'next_message_received_focused': [ True, '../data/sounds/message2.wav' ],
-		'next_message_received_unfocused': [ True, '../data/sounds/message2.wav' ],
-		'contact_connected': [ True, '../data/sounds/connected.wav' ],
-		'contact_disconnected': [ True, '../data/sounds/disconnected.wav' ],
-		'message_sent': [ True, '../data/sounds/sent.wav' ],
-		'muc_message_highlight': [ True, '../data/sounds/gc_message1.wav', _('Sound to play when a group chat message contains one of the words in muc_highlight_words, or when a group chat message contains your nickname.')],
-		'muc_message_received': [ False, '../data/sounds/gc_message2.wav', _('Sound to play when any MUC message arrives.') ],
-		'gmail_received': [ False, '../data/sounds/message1.wav' ],
+		'first_message_received': [ True, 'message1.wav' ],
+		'next_message_received_focused': [ True, 'message2.wav' ],
+		'next_message_received_unfocused': [ True, 'message2.wav' ],
+		'contact_connected': [ True, 'connected.wav' ],
+		'contact_disconnected': [ True, 'disconnected.wav' ],
+		'message_sent': [ True, 'sent.wav' ],
+		'muc_message_highlight': [ True, 'gc_message1.wav', _('Sound to play when a group chat message contains one of the words in muc_highlight_words, or when a group chat message contains your nickname.')],
+		'muc_message_received': [ False, 'gc_message2.wav', _('Sound to play when any MUC message arrives.') ],
+		'gmail_received': [ False, 'message1.wav' ],
 	}
 
 	themes_default = {
@@ -471,11 +505,11 @@ class Config:
 			cb(data, opt, None, self.__options[opt])
 		for opt in self.__options_per_key:
 			cb(data, opt, None, None)
-			dict = self.__options_per_key[opt][1]
-			for opt2 in dict.keys():
+			dict_ = self.__options_per_key[opt][1]
+			for opt2 in dict_.keys():
 				cb(data, opt2, [opt], None)
-				for opt3 in dict[opt2]:
-					cb(data, opt3, [opt, opt2], dict[opt2][opt3])
+				for opt3 in dict_[opt2]:
+					cb(data, opt3, [opt, opt2], dict_[opt2][opt3])
 
 	def get_children(self, node=None):
 		''' Tree-like interface '''
@@ -553,7 +587,7 @@ class Config:
 		if optname not in self.__options:
 			return None
 		return self.__options[optname][OPT_VAL]
-		
+
 	def get_desc(self, optname):
 		if optname not in self.__options:
 			return None
@@ -570,7 +604,7 @@ class Config:
 		if typename not in self.__options_per_key:
 #			raise RuntimeError, 'option %s does not exist' % typename
 			return
-		
+
 		opt = self.__options_per_key[typename]
 		if name in opt[1]:
 			# we already have added group name before
@@ -585,7 +619,7 @@ class Config:
 		opt = self.__options_per_key[typename]
 		if subname is None:
 			del opt[1][name]
-		# if subname is specified, delete the item in the group.	
+		# if subname is specified, delete the item in the group.
 		elif subname in opt[1][name]:
 			del opt[1][name][subname]
 
@@ -595,11 +629,11 @@ class Config:
 			return
 		if not key:
 			return
-		dict = self.__options_per_key[optname][1]
-		if key not in dict:
-#			raise RuntimeError, '%s is not a key of %s' % (key, dict)
+		dict_ = self.__options_per_key[optname][1]
+		if key not in dict_:
+#			raise RuntimeError, '%s is not a key of %s' % (key, dict_)
 			self.add_per(optname, key)
-		obj = dict[key]
+		obj = dict_[key]
 		if subname not in obj:
 #			raise RuntimeError, '%s is not a key of %s' % (subname, obj)
 			return
@@ -613,16 +647,16 @@ class Config:
 	def get_per(self, optname, key = None, subname = None): # per_group_of_option
 		if optname not in self.__options_per_key:
 			return None
-		dict = self.__options_per_key[optname][1]
+		dict_ = self.__options_per_key[optname][1]
 		if not key:
-			return dict.keys()
-		if key not in dict:
+			return dict_.keys()
+		if key not in dict_:
 			if optname in self.__options_per_key \
 			and subname in self.__options_per_key[optname][0]:
 				return self.__options_per_key \
 					[optname][0][subname][1]
 			return None
-		obj = dict[key]
+		obj = dict_[key]
 		if not subname:
 			return obj
 		if subname not in obj:
@@ -632,12 +666,12 @@ class Config:
 	def get_desc_per(self, optname, key = None, subname = None):
 		if optname not in self.__options_per_key:
 			return None
-		dict = self.__options_per_key[optname][1]
+		dict_ = self.__options_per_key[optname][1]
 		if not key:
 			return None
-		if key not in dict:
+		if key not in dict_:
 			return None
-		obj = dict[key]
+		obj = dict_[key]
 		if not subname:
 			return None
 		if subname not in obj:
@@ -649,12 +683,12 @@ class Config:
 	def get_restart_per(self, optname, key = None, subname = None):
 		if optname not in self.__options_per_key:
 			return False
-		dict = self.__options_per_key[optname][1]
+		dict_ = self.__options_per_key[optname][1]
 		if not key:
 			return False
-		if key not in dict:
+		if key not in dict_:
 			return False
-		obj = dict[key]
+		obj = dict_[key]
 		if not subname:
 			return False
 		if subname not in obj:
