@@ -217,6 +217,7 @@ class Connection(ConnectionHandlers):
 	# We are doing disconnect at so many places, better use one function in all
 	def disconnect(self, on_purpose=False):
 		gajim.interface.music_track_changed(None, None, self.name)
+		self.reset_awaiting_pep()
 		self.on_purpose = on_purpose
 		self.connected = 0
 		self.time_to_reconnect = None
@@ -973,16 +974,16 @@ class Connection(ConnectionHandlers):
 		self.priority = priority
 		self.dispatch('STATUS', 'invisible')
 		if initial:
-			#ask our VCard
+			# ask our VCard
 			self.request_vcard(None)
 
-			#Get bookmarks from private namespace
+			# Get bookmarks from private namespace
 			self.get_bookmarks()
 
-			#Get annotations
+			# Get annotations
 			self.get_annotations()
 
-			#Inform GUI we just signed in
+			# Inform GUI we just signed in
 			self.dispatch('SIGNED_IN', ())
 
 	def test_gpg_passphrase(self, password):
@@ -1366,13 +1367,14 @@ class Connection(ConnectionHandlers):
 					try:
 						gajim.logger.write(kind, jid, log_msg)
 					except exceptions.PysqliteOperationalError, e:
-						self.dispatch('ERROR', (_('Disk Write Error'), str(e)))
+						self.dispatch('DB_ERROR', (_('Disk Write Error'), str(e)))
 					except exceptions.DatabaseMalformed:
 						pritext = _('Database Error')
 						sectext = _('The database file (%s) cannot be read. Try to '
 							'repair it (see http://trac.gajim.org/wiki/DatabaseBackup)'
 							' or remove it (all history will be lost).') % \
 							common.logger.LOG_DB_PATH
+						self.dispatch('DB_ERROR', (pritext, sectext))
 		self.dispatch('MSGSENT', (jid, msg, keyID))
 
 		if callback:
@@ -1791,7 +1793,7 @@ class Connection(ConnectionHandlers):
 				last_date = time.time() - gajim.config.get(
 					'muc_restore_timeout') * 60
 			else:
-				last_time = min(last_date, time.time() - gajim.config.get(
+				last_date = min(last_date, time.time() - gajim.config.get(
 					'muc_restore_timeout') * 60)
 			last_date = time.strftime('%Y-%m-%dT%H:%M:%SZ', time.gmtime(last_date))
 			t.setTag('history', {'maxstanzas': gajim.config.get(
