@@ -92,6 +92,13 @@ class Constants:
 			self.TYPE_MRIM,
 		) = range(14)
 
+		(
+			self.SUBSCRIPTION_NONE,
+			self.SUBSCRIPTION_TO,
+			self.SUBSCRIPTION_FROM,
+			self.SUBSCRIPTION_BOTH,
+		) = range(4)
+
 constants = Constants()
 
 class Logger:
@@ -123,8 +130,8 @@ class Logger:
 		# if locked, wait up to 20 sec to unlock
 		# before raise (hopefully should be enough)
 
-		self.con = sqlite.connect(LOG_DB_FILE, timeout = 20.0,
-			isolation_level = 'IMMEDIATE')
+		self.con = sqlite.connect(LOG_DB_FILE, timeout=20.0,
+			isolation_level='IMMEDIATE')
 		os.chdir(back)
 		self.cur = self.con.cursor()
 		self.set_synchronous(False)
@@ -153,7 +160,8 @@ class Logger:
 	def get_jids_already_in_db(self):
 		try:
 			self.cur.execute('SELECT jid FROM jids')
-			rows = self.cur.fetchall() # list of tupples: [(u'aaa@bbb',), (u'cc@dd',)]
+			# list of tupples: [(u'aaa@bbb',), (u'cc@dd',)]
+			rows = self.cur.fetchall()
 		except sqlite.DatabaseError:
 			raise exceptions.DatabaseMalformed
 		self.jids_already_in = []
@@ -176,9 +184,9 @@ class Logger:
 		pm (so higly unlikely) and if we fail we do not go chaos
 		(user will see the first pm as if it was message in room's public chat)
 		and after that all okay'''
-		
-		if jid.find('/') > -1: 
-			possible_room_jid, possible_nick = jid.split('/', 1)
+
+		if jid.find('/') > -1:
+			possible_room_jid = jid.split('/', 1)[0]
 			return self.jid_is_room_jid(possible_room_jid)
 		else:
 			# it's not a full jid, so it's not a pm one
@@ -193,7 +201,7 @@ class Logger:
 		else:
 			return True
 
-	def get_jid_id(self, jid, typestr = None):
+	def get_jid_id(self, jid, typestr=None):
 		'''jids table has jid and jid_id
 		logs table has log_id, jid_id, contact_name, time, kind, show, message
 		so to ask logs we need jid_id that matches our jid in jids table
@@ -331,12 +339,35 @@ class Logger:
 		if type_id == constants.TYPE_MRIM:
 			return 'mrim'
 
-	def commit_to_db(self, values, write_unread = False):
-		sql = 'INSERT INTO logs (jid_id, contact_name, time, kind, show, message, subject) VALUES (?, ?, ?, ?, ?, ?, ?)'
+	def convert_human_subscription_values_to_db_api_values(self, sub):
+		'''converts from string style to constant ints for db'''
+		if sub == 'none':
+			return constants.SUBSCRIPTION_NONE
+		if sub == 'to':
+			return constants.SUBSCRIPTION_TO
+		if sub == 'from':
+			return constants.SUBSCRIPTION_FROM
+		if sub == 'both':
+			return constants.SUBSCRIPTION_BOTH
+
+	def convert_db_api_values_to_human_subscription_values(self, sub):
+		'''converts from constant ints for db to string style'''
+		if sub == constants.SUBSCRIPTION_NONE:
+			return 'none'
+		if sub == constants.SUBSCRIPTION_TO:
+			return 'to'
+		if sub == constants.SUBSCRIPTION_FROM:
+			return 'from'
+		if sub == constants.SUBSCRIPTION_BOTH:
+			return 'both'
+
+	def commit_to_db(self, values, write_unread=False):
+		sql = '''INSERT INTO logs (jid_id, contact_name, time, kind, show,
+			message, subject) VALUES (?, ?, ?, ?, ?, ?, ?)'''
 		try:
 			self.cur.execute(sql, values)
 		except sqlite.DatabaseError:
-			raise exceptions.DatabaseMalformed 
+			raise exceptions.DatabaseMalformed
 		except sqlite.OperationalError, e:
 			raise exceptions.PysqliteOperationalError(str(e))
 		message_id = None
@@ -352,7 +383,8 @@ class Logger:
 
 	def insert_unread_events(self, message_id, jid_id):
 		''' add unread message with id: message_id'''
-		sql = 'INSERT INTO unread_messages VALUES (%d, %d)' % (message_id, jid_id)
+		sql = 'INSERT INTO unread_messages VALUES (%d, %d, 0)' % (message_id,
+			jid_id)
 		self.simple_commit(sql)
 
 	def set_read_messages(self, message_ids):
@@ -361,19 +393,31 @@ class Logger:
 		sql = 'DELETE FROM unread_messages WHERE message_id IN (%s)' % ids
 		self.simple_commit(sql)
 
+	def set_shown_unread_msgs(self, msg_id):
+		''' mark unread message as shown un GUI '''
+		sql = 'UPDATE unread_messages SET shown = 1 where message_id = %s' % \
+			msg_id
+		self.simple_commit(sql)
+
+	def reset_shown_unread_messages(self):
+		''' Set shown field to False in unread_messages table '''
+		sql = 'UPDATE unread_messages SET shown = 0'
+		self.simple_commit(sql)
+
 	def get_unread_msgs(self):
 		''' get all unread messages '''
 		all_messages = []
 		try:
 			self.cur.execute(
-				'SELECT message_id from unread_messages')
+				'SELECT message_id, shown from unread_messages')
 			results = self.cur.fetchall()
 		except Exception:
 			pass
 		for message in results:
 			msg_id = message[0]
+			shown = message[1]
 			# here we get infos for that message, and related jid from jids table
-			# do NOT change order of SELECTed things, unless you change function(s) 
+			# do NOT change order of SELECTed things, unless you change function(s)
 			# that called this function
 			self.cur.execute('''
 				SELECT logs.log_line_id, logs.message, logs.time, logs.subject,
@@ -387,11 +431,10 @@ class Logger:
 				# Log line is no more in logs table. remove it from unread_messages
 				self.set_read_messages([msg_id])
 				continue
-			all_messages.append(results[0])
+			all_messages.append(results[0] + (shown,))
 		return all_messages
 
-	def write(self, kind, jid, message = None, show = None, tim = None,
-	subject = None):
+	def write(self, kind, jid, message=None, show=None, tim=None, subject=None):
 		'''write a row (status, gcstatus, message etc) to logs database
 		kind can be status, gcstatus, gc_msg, (we only recv for those 3),
 		single_msg_recv, chat_msg_recv, chat_msg_sent, single_msg_sent
@@ -473,14 +516,14 @@ class Logger:
 		return self.commit_to_db(values, write_unread)
 
 	def get_last_conversation_lines(self, jid, restore_how_many_rows,
-		pending_how_many, timeout, account):
+	pending_how_many, timeout, account):
 		'''accepts how many rows to restore and when to time them out (in minutes)
 		(mark them as too old) and number of messages that are in queue
 		and are already logged but pending to be viewed,
 		returns a list of tupples containg time, kind, message,
 		list with empty tupple if nothing found to meet our demands'''
 		try:
-			jid_id = self.get_jid_id(jid)
+			self.get_jid_id(jid)
 		except exceptions.PysqliteOperationalError, e:
 			# Error trying to create a new jid_id. This means there is no log
 			return []
@@ -518,11 +561,11 @@ class Logger:
 		return start_of_day
 
 	def get_conversation_for_date(self, jid, year, month, day, account):
-		'''returns contact_name, time, kind, show, message
+		'''returns contact_name, time, kind, show, message, subject
 		for each row in a list of tupples,
 		returns list with empty tupple if we found nothing to meet our demands'''
 		try:
-			jid_id = self.get_jid_id(jid)
+			self.get_jid_id(jid)
 		except exceptions.PysqliteOperationalError, e:
 			# Error trying to create a new jid_id. This means there is no log
 			return []
@@ -533,7 +576,7 @@ class Logger:
 		last_second_of_day = start_of_day + seconds_in_a_day - 1
 
 		self.cur.execute('''
-			SELECT contact_name, time, kind, show, message FROM logs
+			SELECT contact_name, time, kind, show, message, subject FROM logs
 			WHERE (%s)
 			AND time BETWEEN %d AND %d
 			ORDER BY time
@@ -547,12 +590,12 @@ class Logger:
 		for each row in a list of tupples,
 		returns list with empty tupple if we found nothing to meet our demands'''
 		try:
-			jid_id = self.get_jid_id(jid)
+			self.get_jid_id(jid)
 		except exceptions.PysqliteOperationalError, e:
 			# Error trying to create a new jid_id. This means there is no log
 			return []
 
-		if False: #query.startswith('SELECT '): # it's SQL query (FIXME)
+		if False: # query.startswith('SELECT '): # it's SQL query (FIXME)
 			try:
 				self.cur.execute(query)
 			except sqlite.OperationalError, e:
@@ -574,7 +617,7 @@ class Logger:
 	def get_days_with_logs(self, jid, year, month, max_day, account):
 		'''returns the list of days that have logs (not status messages)'''
 		try:
-			jid_id = self.get_jid_id(jid)
+			self.get_jid_id(jid)
 		except exceptions.PysqliteOperationalError, e:
 			# Error trying to create a new jid_id. This means there is no log
 			return []
@@ -586,8 +629,12 @@ class Logger:
 		seconds_in_a_day = 86400 # 60 * 60 * 24
 		last_second_of_month = start_of_month + (seconds_in_a_day * max_day) - 1
 
+		# Select times and 'floor' them to time 0:00
+		# (by dividing, they are integers)
+		# and take only one of the same values (distinct)
+		# Now we have timestamps of time 0:00 of every day with logs
 		self.cur.execute('''
-			SELECT time FROM logs
+			SELECT DISTINCT time/(86400)*86400 FROM logs
 			WHERE (%s)
 			AND time BETWEEN %d AND %d
 			AND kind NOT IN (%d, %d)
@@ -596,37 +643,13 @@ class Logger:
 			constants.KIND_STATUS, constants.KIND_GCSTATUS))
 		result = self.cur.fetchall()
 
-		# Copy all interesting times in a temporary table
-		try:
-			self.cur.execute('CREATE TEMPORARY TABLE temp_table(time,INTEGER)')
-		except sqlite.OperationalError, e:
-			raise exceptions.PysqliteOperationalError(str(e))
+		# convert timestamps to day of month
 		for line in result:
-			self.cur.execute('''
-				INSERT INTO temp_table (time) VALUES (%d)
-				''' % (line[0]))
+			days_with_logs[0:0]=[time.gmtime(line[0])[2]]
 
-		# then search in this small temp table for each day
-		for day in xrange(1, max_day + 1):  # count from 1 to 28 or to 30 or to 31
-			start_of_day = self.get_unix_time_from_date(year, month, day)
-			last_second_of_day = start_of_day + seconds_in_a_day - 1
-
-			# just ask one row to see if we have sth for this date
-			self.cur.execute('''
-				SELECT time FROM temp_table
-				WHERE time BETWEEN %d AND %d
-				LIMIT 1
-				''' % (start_of_day, last_second_of_day))
-			result = self.cur.fetchone()
-			if result:
-				days_with_logs[0:0]=[day]
-
-		# Delete temporary table
-		self.cur.execute('DROP TABLE temp_table')
-		result = self.cur.fetchone()
 		return days_with_logs
 
-	def get_last_date_that_has_logs(self, jid, account = None, is_room = False):
+	def get_last_date_that_has_logs(self, jid, account=None, is_room=False):
 		'''returns last time (in seconds since EPOCH) for which
 		we had logs (excluding statuses)'''
 		where_sql = ''
@@ -737,10 +760,12 @@ class Logger:
 		return answer
 
 	# A longer note here:
-	# The database contains a blob field. Pysqlite seems to need special care for such fields.
+	# The database contains a blob field. Pysqlite seems to need special care for
+	# such fields.
 	# When storing, we need to convert string into buffer object (1).
-	# When retrieving, we need to convert it back to a string to decompress it. (2)
-	# GzipFile needs a file-like object, StringIO emulates file for plain strings.
+	# When retrieving, we need to convert it back to a string to decompress it.
+	# (2)
+	# GzipFile needs a file-like object, StringIO emulates file for plain strings
 	def iter_caps_data(self):
 		''' Iterate over caps cache data stored in the database.
 		The iterator values are pairs of (node, ver, ext, identities, features):
@@ -751,7 +776,7 @@ class Logger:
 		# the data field contains binary object (gzipped data), this is a hack
 		# to get that data without trying to convert it to unicode
 		try:
-			self.cur.execute('SELECT hash_method, hash, data FROM caps_cache;');
+			self.cur.execute('SELECT hash_method, hash, data FROM caps_cache;')
 		except sqlite.OperationalError:
 			# might happen when there's no caps_cache table yet
 			# -- there's no data to read anyway then
@@ -759,18 +784,19 @@ class Logger:
 
 		# list of corrupted entries that will be removed
 		to_be_removed = []
-		for hash_method, hash, data in self.cur:
+		for hash_method, hash_, data in self.cur:
 			# for each row: unpack the data field
 			# (format: (category, type, name, category, type, name, ...
 			#   ..., 'FEAT', feature1, feature2, ...).join(' '))
 			# NOTE: if there's a need to do more gzip, put that to a function
 			try:
-				data = GzipFile(fileobj=StringIO(str(data))).read().decode('utf-8').split('\0')
+				data = GzipFile(fileobj=StringIO(str(data))).read().decode(
+					'utf-8').split('\0')
 			except IOError:
 				# This data is corrupted. It probably contains non-ascii chars
-				to_be_removed.append((hash_method, hash))
+				to_be_removed.append((hash_method, hash_))
 				continue
-			i=0
+			i = 0
 			identities = list()
 			features = list()
 			while i < (len(data) - 3) and data[i] != 'FEAT':
@@ -787,13 +813,14 @@ class Logger:
 				i += 1
 
 			# yield the row
-			yield hash_method, hash, identities, features
-		for hash_method, hash in to_be_removed:
-			sql = 'DELETE FROM caps_cache WHERE hash_method = "%s" AND hash = "%s"' % (hash_method, hash)
+			yield hash_method, hash_, identities, features
+		for hash_method, hash_ in to_be_removed:
+			sql = '''DELETE FROM caps_cache WHERE hash_method = "%s" AND
+				hash = "%s"''' % (hash_method, hash_)
 			self.simple_commit(sql)
 
 	def add_caps_entry(self, hash_method, hash_, identities, features):
-		data=[]
+		data = []
 		for identity in identities:
 			# there is no FEAT category
 			if identity['category'] == 'FEAT':
@@ -819,4 +846,126 @@ class Logger:
 		except sqlite.OperationalError, e:
 			print >> sys.stderr, str(e)
 
+	def replace_roster(self, account_name, roster_version, roster):
+		''' Replace current roster in DB by a new one.
+		accout_name is the name of the account to change
+		roster_version is the version of the new roster
+		roster is the new version '''
+		# First we must reset roster_version value to ensure that the server
+		# sends back all the roster at the next connexion if the replacement
+		# didn't work properly.
+		gajim.config.set_per('accounts', account_name, 'roster_version', '')
+
+		account_jid = gajim.get_jid_from_account(account_name)
+		account_jid_id = self.get_jid_id(account_jid)
+
+		# Delete old roster
+		self.remove_roster(account_jid)
+
+		# Fill roster tables with the new roster
+		for jid in roster:
+			self.add_or_update_contact(account_jid, jid, roster[jid]['name'],
+				roster[jid]['subscription'], roster[jid]['ask'],
+				roster[jid]['groups'])
+
+		# At this point, we are sure the replacement works properly so we can
+		# set the new roster_version value.
+		gajim.config.set_per('accounts', account_name, 'roster_version',
+			roster_version)
+
+	def del_contact(self, account_jid, jid):
+		''' Remove jid from account_jid roster. '''
+		try:
+			account_jid_id = self.get_jid_id(account_jid)
+			jid_id = self.get_jid_id(jid)
+		except exceptions.PysqliteOperationalError, e:
+			raise exceptions.PysqliteOperationalError(str(e))
+		self.cur.execute(
+			'DELETE FROM roster_group WHERE account_jid_id=? AND jid_id=?',
+			(account_jid_id, jid_id))
+		self.cur.execute(
+			'DELETE FROM roster_entry WHERE account_jid_id=? AND jid_id=?',
+			(account_jid_id, jid_id))
+		self.con.commit()
+
+	def add_or_update_contact(self, account_jid, jid, name, sub, ask, groups):
+		''' Add or update a contact from account_jid roster. '''
+		if sub == 'remove':
+			self.del_contact(account_jid, jid)
+			return
+
+		try:
+			account_jid_id = self.get_jid_id(account_jid)
+			jid_id = self.get_jid_id(jid)
+		except exceptions.PysqliteOperationalError, e:
+			raise exceptions.PysqliteOperationalError(str(e))
+
+		# Update groups information
+		# First we delete all previous groups information
+		self.cur.execute(
+			'DELETE FROM roster_group WHERE account_jid_id=? AND jid_id=?',
+			(account_jid_id, jid_id))
+		# Then we add all new groups information
+		for group in groups:
+			self.cur.execute('INSERT INTO roster_group VALUES(?, ?, ?)',
+				(account_jid_id, jid_id, group))
+
+		if name is None:
+			name = ''
+
+		self.cur.execute('REPLACE INTO roster_entry VALUES(?, ?, ?, ?, ?)',
+			(account_jid_id, jid_id, name,
+			self.convert_human_subscription_values_to_db_api_values(sub),
+			bool(ask)))
+		self.con.commit()
+
+	def get_roster(self, account_jid):
+		''' Return the accound_jid roster in NonBlockingRoster format. '''
+		data = {}
+		account_jid_id = self.get_jid_id(account_jid)
+
+		# First we fill data with roster_entry informations
+		self.cur.execute('''
+			SELECT j.jid, re.jid_id, re.name, re.subscription, re.ask
+			FROM roster_entry re, jids j
+			WHERE re.account_jid_id=? AND j.jid_id=re.jid_id''', (account_jid_id,))
+		for jid, jid_id, name, subscription, ask in self.cur:
+			data[jid] = {}
+			if name:
+				data[jid]['name'] = name
+			else:
+				data[jid]['name'] = None
+			data[jid]['subscription'] = \
+				self.convert_db_api_values_to_human_subscription_values(
+				subscription)
+			data[jid]['groups'] = []
+			data[jid]['resources'] = {}
+			if ask:
+				data[jid]['ask'] = 'subscribe'
+			else:
+				data[jid]['ask'] = None
+			data[jid]['id'] = jid_id
+
+		# Then we add group for roster entries
+		for jid in data:
+			self.cur.execute('''
+				SELECT group_name FROM roster_group
+				WHERE account_jid_id=? AND jid_id=?''',
+				(account_jid_id, data[jid]['id']))
+			for (group_name,) in self.cur:
+				data[jid]['groups'].append(group_name)
+			del data[jid]['id']
+
+		return data
+
+	def remove_roster(self, account_jid):
+		''' Remove all entry from account_jid roster. '''
+		account_jid_id = self.get_jid_id(account_jid)
+
+		self.cur.execute('DELETE FROM roster_entry WHERE account_jid_id=?',
+			(account_jid_id,))
+		self.cur.execute('DELETE FROM roster_group WHERE account_jid_id=?',
+			(account_jid_id,))
+		self.con.commit()
+
 # vim: se ts=3:
