@@ -33,6 +33,7 @@ from errno import ENOBUFS
 from errno import EINTR
 from errno import EISCONN
 from errno import EINPROGRESS
+from errno import EAFNOSUPPORT
 from xmpp.idlequeue import IdleObject
 MAX_BUFF_LEN = 65536
 
@@ -813,8 +814,14 @@ class Socks5Listener(IdleObject):
 
 	def bind(self):
 		for ai in self.ais:
-			#try the different possibilities (ipv6, ipv4, etc.)
-			self._serv = socket.socket(*ai[:3])
+			# try the different possibilities (ipv6, ipv4, etc.)
+			try:
+				self._serv = socket.socket(*ai[:3])
+			except socket.error, e:
+				if e.args[0] == EAFNOSUPPORT:
+					self.ai = None
+					continue
+				raise
 			self._serv.setsockopt(socket.SOL_SOCKET, socket.SO_REUSEADDR, 1)
 			self._serv.setsockopt(socket.SOL_SOCKET, socket.SO_KEEPALIVE, 1)
 			self._serv.setsockopt(socket.IPPROTO_TCP, socket.TCP_NODELAY, 1)
