@@ -1,4 +1,3 @@
-#!/usr/bin/env python
 # -*- coding:utf-8 -*-
 ## src/gajim-remote.py
 ##
@@ -29,11 +28,12 @@
 
 import sys
 import locale
+import urllib
 import signal
 signal.signal(signal.SIGINT, signal.SIG_DFL) # ^C exits the application
 
 from common import exceptions
-from common import i18n
+from common import i18n # This installs _() function
 
 try:
 	PREFERRED_ENCODING = locale.getpreferredencoding()
@@ -46,12 +46,11 @@ def send_error(error_message):
 	sys.exit(1)
 
 try:
-	if sys.platform == 'darwin':
-		import osx.dbus
-		osx.dbus.load(False)
 	import dbus
 	import dbus.service
 	import dbus.glib
+	# test if dbus-x11 is installed
+	bus = dbus.SessionBus()
 except Exception:
 	print str(exceptions.DbusNotSupported())
 	sys.exit(1)
@@ -115,13 +114,26 @@ class GajimRemote:
 		'"sync with global status" option set'), False)
 					]
 				],
+			'set_priority': [
+					_('Changes the priority of account or accounts'),
+					[
+						(_('priority'), _('priority you want to give to the account'),
+							True),
+						(_('account'), _('change the priority of the given account. '
+							'If not specified, change status of all accounts that have'
+							' "sync with global status" option set'), False)
+					]
+				],
 			'open_chat': [
 					_('Shows the chat dialog so that you can send messages to a contact'),
 					[
 						('jid', _('JID of the contact that you want to chat with'),
 							True),
 						(_('account'), _('if specified, contact is taken from the '
-						'contact list of this account'), False)
+							'contact list of this account'), False),
+						(_('message'),
+							_('message content. The account must be specified or ""'),
+							False)
 					]
 				],
 			'send_chat_message':[
@@ -258,7 +270,8 @@ class GajimRemote:
 					[
 						(_('uri'), _('URI to handle'), True),
 						(_('account'), _('Account in which you want to handle it'),
-							False)
+							False),
+						(_('message'), _('Message content'), False)
 					]
 				],
 			'join_room': [
@@ -283,7 +296,7 @@ class GajimRemote:
 			}
 
 		self.sbus = None
-		if self.argv_len  < 2 or sys.argv[1] not in self.commands.keys():
+		if self.argv_len < 2 or sys.argv[1] not in self.commands.keys():
 			# no args or bad args
 			send_error(self.compose_help())
 		self.command = sys.argv[1]
@@ -387,54 +400,41 @@ class GajimRemote:
 	def make_arguments_row(self, args):
 		''' return arguments list. Mandatory arguments are enclosed with:
 		'<', '>', optional arguments - with '[', ']' '''
-		str = ''
-		for argument in args:
-			str += ' '
-			if argument[2]:
-				str += '<'
+		s = ''
+		for arg in args:
+			if arg[2]:
+				s += ' <' + arg[0] + '>'
 			else:
-				str += '['
-			str += argument[0]
-			if argument[2]:
-				str += '>'
-			else:
-				str += ']'
-		return str
+				s += ' [' + arg[0] + ']'
+		return s
 
 	def help_on_command(self, command):
 		''' return help message for a given command '''
 		if command in self.commands:
 			command_props = self.commands[command]
 			arguments_str = self.make_arguments_row(command_props[1])
-			str = _('Usage: %(basename)s %(command)s %(arguments)s \n\t %(help)s')\
+			str_ = _('Usage: %(basename)s %(command)s %(arguments)s \n\t %(help)s')\
 				% {'basename': BASENAME, 'command': command,
 				'arguments': arguments_str, 'help': command_props[0]}
 			if len(command_props[1]) > 0:
-				str += '\n\n' + _('Arguments:') + '\n'
+				str_ += '\n\n' + _('Arguments:') + '\n'
 				for argument in command_props[1]:
-					str += ' ' +  argument[0] + ' - ' + argument[1] + '\n'
-			return str
+					str_ += ' ' + argument[0] + ' - ' + argument[1] + '\n'
+			return str_
 		send_error(_('%s not found') % command)
 
 	def compose_help(self):
 		''' print usage, and list available commands '''
-		str = _('Usage: %s command [arguments]\nCommand is one of:\n' ) % BASENAME
-		commands = sorted(self.commands.keys())
-		for command in commands:
-			str += '  ' + command
-			for argument in self.commands[command][1]:
-				str += ' '
-				if argument[2]:
-					str += '<'
+		s = _('Usage: %s command [arguments]\nCommand is one of:\n' ) % BASENAME
+		for command in sorted(self.commands):
+			s += '  ' + command
+			for arg in self.commands[command][1]:
+				if arg[2]:
+					s += ' <' + arg[0] + '>'
 				else:
-					str += '['
-				str += argument[0]
-				if argument[2]:
-					str += '>'
-				else:
-					str += ']'
-			str += '\n'
-		return str
+					s += ' [' + arg[0] + ']'
+			s += '\n'
+		return s
 
 	def print_info(self, level, prop_dict, encode_return = False):
 		''' return formated string from data structure '''
@@ -513,6 +513,8 @@ class GajimRemote:
 		self.arguments += ['']*(len(args)-i)
 
 	def handle_uri(self):
+		if len(sys.argv) < 3:
+			send_error(_('No uri given'))
 		if not sys.argv[2].startswith('xmpp:'):
 			send_error(_('Wrong uri'))
 		sys.argv[2] = sys.argv[2][5:]
@@ -520,7 +522,30 @@ class GajimRemote:
 		if not '?' in uri:
 			self.command = sys.argv[1] = 'open_chat'
 			return
+		if 'body=' in uri:
+			# Open chat window and paste the text in the input message dialog
+			self.command = sys.argv[1] = 'open_chat'
+			message = uri.split('body=')
+			message = message[1].split(';')[0]
+			try:
+				message = urllib.unquote(message)
+			except UnicodeDecodeError:
+				pass
+			sys.argv[2] = uri.split('?')[0]
+			if len(sys.argv) == 4:
+				# jid in the sys.argv
+				sys.argv.append(message)
+			else:
+				sys.argv.append('')
+				sys.argv.append(message)
+				sys.argv[3] = ''
+				sys.argv[4] = message
+			return
 		(jid, action) = uri.split('?', 1)
+		try:
+			jid = urllib.unquote(jid)
+		except UnicodeDecodeError:
+			pass
 		sys.argv[2] = jid
 		if action == 'join':
 			self.command = sys.argv[1] = 'join_room'
@@ -529,7 +554,10 @@ class GajimRemote:
 			sys.argv.append(sys.argv[3])
 			sys.argv[3] = ''
 			return
-
+		if action.startswith('roster'):
+			# Add contact to roster
+			self.command = sys.argv[1] = 'add_contact'
+			return
 		sys.exit(0)
 
 	def call_remote_method(self):
