@@ -29,6 +29,7 @@
 
 import os
 import time
+import locale
 import gtk
 import pango
 import gobject
@@ -317,6 +318,7 @@ class GroupchatControl(ChatControlBase):
 		id_ = self.list_treeview.connect('style-set',
 			self.on_list_treeview_style_set)
 		self.handlers[id_] = self.list_treeview
+		self.resize_from_another_muc = False
 		# we want to know when the the widget resizes, because that is
 		# an indication that the hpaned has moved...
 		# FIXME: Find a better indicator that the hpaned has moved.
@@ -393,9 +395,7 @@ class GroupchatControl(ChatControlBase):
 		nick1 = nick1.decode('utf-8')
 		nick2 = nick2.decode('utf-8')
 		if type1 == 'role':
-			if nick1 < nick2:
-				return -1
-			return 1
+			return locale.strcoll(nick1, nick2)
 		if type1 == 'contact':
 			gc_contact1 = gajim.contacts.get_gc_contact(self.account,
 				self.room_jid, nick1)
@@ -419,11 +419,7 @@ class GroupchatControl(ChatControlBase):
 		# We compare names
 		name1 = gc_contact1.get_shown_name()
 		name2 = gc_contact2.get_shown_name()
-		if name1.lower() < name2.lower():
-			return -1
-		if name2.lower() < name1.lower():
-			return 1
-		return 0
+		return locale.strcoll(name1.lower(), name2.lower())
 
 	def on_msg_textview_populate_popup(self, textview, menu):
 		'''we override the default context menu and we prepend Clear
@@ -446,17 +442,29 @@ class GroupchatControl(ChatControlBase):
 
 		menu.show_all()
 
+	def resize_occupant_treeview(self, position):
+		self.resize_from_another_muc = True
+		self.hpaned.set_position(position)
+		def reset_flag():
+			self.resize_from_another_muc = False
+		# Reset the flag when everything will be redrawn, and in particular when
+		# on_treeview_size_allocate will have been called.
+		gobject.idle_add(reset_flag)
+
 	def on_treeview_size_allocate(self, widget, allocation):
 		'''The MUC treeview has resized. Move the hpaned in all tabs to match'''
+		if self.resize_from_another_muc:
+			# Don't send the event to other MUC
+			return
 		hpaned_position = self.hpaned.get_position()
 		for account in gajim.gc_connected:
 			for room_jid in [i for i in gajim.gc_connected[account] if \
-			gajim.gc_connected[account][i]]:
+			gajim.gc_connected[account][i] and i != self.room_jid]:
 				ctrl = gajim.interface.msg_win_mgr.get_gc_control(room_jid, account)
 				if not ctrl:
 					ctrl = gajim.interface.minimized_controls[account][room_jid]
 				if ctrl:
-					ctrl.hpaned.set_position(hpaned_position)
+					ctrl.resize_occupant_treeview(hpaned_position)
 
 	def iter_contact_rows(self):
 		'''iterate over all contact rows in the tree model'''
@@ -669,7 +677,7 @@ class GroupchatControl(ChatControlBase):
 
 		ag = gtk.accel_groups_from_object(self.parent_win.window)[0]
 		change_nick_menuitem.add_accelerator('activate', ag, gtk.keysyms.n,
-			gtk.gdk.CONTROL_MASK, gtk.ACCEL_VISIBLE)
+			gtk.gdk.CONTROL_MASK | gtk.gdk.SHIFT_MASK, gtk.ACCEL_VISIBLE)
 		change_subject_menuitem.add_accelerator('activate', ag,
 			gtk.keysyms.t, gtk.gdk.MOD1_MASK, gtk.ACCEL_VISIBLE)
 		bookmark_room_menuitem.add_accelerator('activate', ag, gtk.keysyms.b,
@@ -741,7 +749,7 @@ class GroupchatControl(ChatControlBase):
 		# destroy accelerators
 		ag = gtk.accel_groups_from_object(self.parent_win.window)[0]
 		change_nick_menuitem.remove_accelerator(ag, gtk.keysyms.n,
-			gtk.gdk.CONTROL_MASK)
+			gtk.gdk.CONTROL_MASK | gtk.gdk.SHIFT_MASK)
 		change_subject_menuitem.remove_accelerator(ag, gtk.keysyms.t,
 			gtk.gdk.MOD1_MASK)
 		bookmark_room_menuitem.remove_accelerator(ag, gtk.keysyms.b,
@@ -1804,12 +1812,15 @@ class GroupchatControl(ChatControlBase):
 
 			gc_refer_to_nick_char = gajim.config.get('gc_refer_to_nick_char')
 			with_refer_to_nick_char = False
+			after_nick_len = 1 # the space that is printed after we type [Tab]
 
 			# first part of this if : works fine even if refer_to_nick_char
-			if gc_refer_to_nick_char and begin.endswith(gc_refer_to_nick_char):
+			if gc_refer_to_nick_char and text.endswith(
+			gc_refer_to_nick_char + ' '):
 				with_refer_to_nick_char = True
+				after_nick_len = len(gc_refer_to_nick_char + ' ')
 			if len(self.nick_hits) and self.last_key_tabs and \
-			text[:-len(gc_refer_to_nick_char + ' ')].endswith(self.nick_hits[0]):
+			text[:-after_nick_len].endswith(self.nick_hits[0]):
 				# we should cycle
 				# Previous nick in list may had a space inside, so we check text and
 				# not splitted_text and store it into 'begin' var
